gshapa package
==============

Submodules
----------

gshapa.gshapa module
--------------------

.. automodule:: gshapa.gshapa
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gshapa
   :members:
   :undoc-members:
   :show-inheritance:
